summaryrefslogtreecommitdiff
path: root/src/map_int.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/map_int.h')
-rw-r--r--src/map_int.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/map_int.h b/src/map_int.h
index 6fea432..6e95c69 100644
--- a/src/map_int.h
+++ b/src/map_int.h
@@ -29,7 +29,7 @@ struct HXmap_private {
* @min_load: minimum number of elements before table gets shrunk
* @tid: transaction ID, used to track relayouts
*/
-struct HXhmap {
+struct HXumap {
struct HXmap_private super;
struct HXlist_head *bk_array;
@@ -37,11 +37,11 @@ struct HXhmap {
};
/**
* @anchor: anchor point in struct HXhmap_node
* @key: data that works as key
* @data: data that works as value
*/
-struct HXhmap_node {
+struct HXumap_node {
struct HXlist_head anchor;
/* HXmap_node */
union {
@@ -59,9 +59,9 @@ struct HXmap_trav {
unsigned int flags;
};
-struct HXhmap_trav {
+struct HXumap_trav {
struct HXmap_trav super;
- const struct HXhmap *hmap;
+ const struct HXumap *hmap;
const struct HXlist_head *head;
unsigned int bk_current, tid;
};
@@ -86,8 +86,8 @@ enum {
* @sub: leaves
* @color: RBtree-specific node color
*/
-struct HXrbtree_node {
- struct HXrbtree_node *sub[2];
+struct HXrbnode {
+ struct HXrbnode *sub[2];
/* HXmap_node */
union {
void *key;
@@ -102,7 +102,7 @@ struct HXrbtree_node {
struct HXrbtree {
struct HXmap_private super;
- struct HXrbtree_node *root;
+ struct HXrbnode *root;
unsigned int tid;
};
@@ -110,9 +110,9 @@ struct HXrbtrav {
struct HXmap_trav super;
unsigned int tid; /* last seen btree transaction */
const struct HXrbtree *tree;
- struct HXrbtree_node *current; /* last visited node */
+ struct HXrbnode *current; /* last visited node */
char *checkpoint;
- struct HXrbtree_node *path[RBT_MAXDEP]; /* stored path */
+ struct HXrbnode *path[RBT_MAXDEP]; /* stored path */
unsigned char dir[RBT_MAXDEP];
unsigned char depth;
};
@@ -37,11 +37,11 @@ struct HXhmap {
};
/**
- * @anchor: anchor point in struct HXhmap_node
+ * @anchor: anchor point in struct HXumap_node
* @key: data that works as key
* @data: data that works as value